pycocoa.runtime.ObjCConstant

Package pycocoa :: Module runtime :: Class ObjCConstant |
[frames] | no frames]

# Class ObjCConstant

    object --+
             |
     _ObjCBase --+
                 |
      ObjCInstance --+
                     |
                    ObjCConstant

Python wrapper for an ObjC constant.

Instance Methods
Inherited from `ObjCInstance`: `__del__`, `__getattr__`, `__str__`, `retained`, `set_ivar` Inherited from `_ObjCBase`: `__repr__` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Static Methods
a new object with type S, a subtype of T |
__new__(cls, dylib, name, const_t=<class 'pycocoa.octypes.ObjC_t'>) New ObjCConstant pointer constant in a `dylib`. |

Properties
Inherited from `ObjCInstance`: `Type`, `from_py2NS`, `inPool`, `name`, `objc_class`, `objc_classname`, `objc_description`, `ptr` Inherited from `_ObjCBase`: `description`, `typename` Inherited from `object`: `__class__`

Method Details

### __new__(cls, dylib, name, const_t=<class 'pycocoa.octypes.ObjC_t'>) Static Method |
New ObjCConstant pointer constant in a `dylib`. Parameters: `dylib` - The library (`ctypes.CDLL`). `name` - The constant's name (`str` or `bytes`). `const_t` - C type (`ObjC_t` or other `ctypes`_t). Returns: a new object with type S, a subtype of T Raises: `RuntimeError` - An NSAutoreleasePool ObjC instance is created with `cached=False`. Overrides: object.__new__